@@ -3,12 +3,12 @@ import os
 from queue import Queue
 import shutil
 import unittest
+from threading import Thread
 
 from executorlib.cache.subprocess_spawner import (
     execute_in_subprocess,
     terminate_subprocess,
 )
-from executorlib.standalone.thread import RaisingThread
 
 try:
     from executorlib.cache.executor import FileExecutor, create_file_executor
@@ -57,7 +57,8 @@ class TestCacheExecutorSerial(unittest.TestCase):
             with FileExecutor(
                 execute_function=execute_in_subprocess, disable_dependencies=True
             ) as exe:
-                exe.submit(my_funct, 1, b=exe.submit(my_funct, 1, b=2))
+                fs = exe.submit(my_funct, 1, b=exe.submit(my_funct, 1, b=2))
+                fs.result()
 
     def test_executor_working_directory(self):
         cwd = os.path.join(os.path.dirname(__file__), "executables")
@@ -81,7 +82,7 @@ class TestCacheExecutorSerial(unittest.TestCase):
         )
         cache_dir = os.path.abspath("cache")
         os.makedirs(cache_dir, exist_ok=True)
-        process = RaisingThread(
+        process = Thread(
             target=execute_tasks_h5,
             kwargs={
                 "future_queue": q,
@@ -122,7 +123,7 @@ class TestCacheExecutorSerial(unittest.TestCase):
         )
         cache_dir = os.path.abspath("cache")
         os.makedirs(cache_dir, exist_ok=True)
-        process = RaisingThread(
+        process = Thread(
             target=execute_tasks_h5,
             kwargs={
                 "future_queue": q,
@@ -163,7 +164,7 @@ class TestCacheExecutorSerial(unittest.TestCase):
         )
         cache_dir = os.path.abspath("cache")
         os.makedirs(cache_dir, exist_ok=True)
-        process = RaisingThread(
+        process = Thread(
             target=execute_tasks_h5,
             kwargs={
                 "future_queue": q,
